You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by da...@apache.org on 2008/03/30 16:48:16 UTC

svn commit: r642753 - in /activemq/camel/trunk/camel-core/src/main/java/org/apache/camel: ./ builder/ component/jmx/ converter/jaxp/ impl/ impl/converter/ management/ model/ model/config/ model/language/ processor/ processor/loadbalancer/ spi/ util/ ut...

Author: davsclaus
Date: Sun Mar 30 07:47:58 2008
New Revision: 642753

URL: http://svn.apache.org/viewvc?rev=642753&view=rev
Log:
CAMEL-404 fixed javadoc warnings (camel-core)
CAMEL-415 parallelprocessing not used

Modified:
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/AsyncCallback.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/AsyncProcessor.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/CamelContext.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/CamelExchangeException.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/CamelTemplate.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/Exchange.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/Message.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/NoSuchEndpointException.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/ProducerTemplate.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/Route.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/RuntimeExchangeException.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/RouteBuilder.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/component/jmx/JMXMessage.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/converter/jaxp/BytesSource.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/converter/jaxp/StringSource.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/converter/jaxp/XmlConverter.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/DefaultCamelContext.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/DefaultConsumer.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/LoggingExceptionHandler.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/MessageSupport.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/converter/AnnotationTypeConverterLoader.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/management/CamelNamingStrategy.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/ProcessorType.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/RouteContainer.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/config/StreamResequencerConfig.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/language/ExpressionType.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/Aggregator.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/ErrorHandlerSupport.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/loadbalancer/TopicLoadBalancer.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/spi/LifecycleStrategy.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/spi/TypeConverterAware.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/CamelContextHelper.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/DefaultTimeoutMap.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/ExchangeHelper.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/ObjectHelper.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/ProducerCache.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/jndi/JndiContext.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/view/NodeData.java

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/AsyncCallback.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/AsyncCallback.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/AsyncCallback.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/AsyncCallback.java Sun Mar 30 07:47:58 2008
@@ -18,15 +18,15 @@
 
 
 /**
- * The callback interface for an {@see AsyncProcessor} so that it can 
- * notify you when an {@see Exchange} has completed. 
+ * The callback interface for an {@link AsyncProcessor} so that it can
+ * notify you when an {@link Exchange} has completed. 
  */
 public interface AsyncCallback {
     
     /**
      * This method is invoked once the Exchange is completed.  If an error 
      * occurred while processing the exchange, the exception field of the 
-     * {@see Exchange} being processed will hold the error. 
+     * {@link Exchange} being processed will hold the error. 
      *  
      * @param doneSynchronously set to true if the processing of the exchange was completed synchronously thread.
      */

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/AsyncProcessor.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/AsyncProcessor.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/AsyncProcessor.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/AsyncProcessor.java Sun Mar 30 07:47:58 2008
@@ -19,9 +19,10 @@
 
 
 /**
- * A more complex version of {@see Processor} which supports asynchronous
- * processing of the {@see Exchange}.  Any processor can be coerced to
- * have an {@see AsyncProcessor} interface by using the {@see AsyncProcessorTypeConverter.convert()}
+ * A more complex version of {@link Processor} which supports asynchronous
+ * processing of the {@link Exchange}.  Any processor can be coerced to
+ * have an {@link AsyncProcessor} interface by using the
+ * {@link org.apache.camel.impl.converter.AsyncProcessorTypeConverter#convert AsyncProcessorTypeConverter.covert}
  * method.
  * 
  * @version $Revision$
@@ -29,11 +30,11 @@
 public interface AsyncProcessor extends Processor {
 
     /**
-     * Processes the message exchange.  Similar to {@see Processor.process}, but
+     * Processes the message exchange.  Similar to {@link Processor#process}, but
      * the caller supports having the exchange asynchronously processed.
      *
-     * @param exchange the exchange to process
-     * @param  callback The @{see AsyncCallback} will be invoked when the processing
+     * @param exchange the {@link Exchange} to process
+     * @param  callback the {@link AsyncCallback} will be invoked when the processing
      *         of the exchange is completed. If the exchange is completed synchronously, then the 
      *         callback is also invoked synchronously.  The callback should therefore be careful of
      *         starting recursive loop.

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/CamelContext.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/CamelContext.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/CamelContext.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/CamelContext.java Sun Mar 30 07:47:58 2008
@@ -73,7 +73,7 @@
      *
      * @param componentName the name of the component
      * @param factory       used to create a new component instance if the component was not previously added.
-     * @return
+     * @return the component
      */
     Component getOrCreateComponent(String componentName, Callable<Component> factory);
 
@@ -81,16 +81,16 @@
     //-----------------------------------------------------------------------
 
     /**
-     * Resolves the given URI to an {@see Endpoint}.  If the URI has a singleton endpoint
-     * registered, then the singleton is returned.  Otherwise, a new {@see Endpoint} is created
+     * Resolves the given URI to an {@link Endpoint}.  If the URI has a singleton endpoint
+     * registered, then the singleton is returned.  Otherwise, a new {@link Endpoint} is created
      * and if the endpoint is a singleton it is registered as a singleton endpoint.
      */
     Endpoint getEndpoint(String uri);
 
     /**
-     * Resolves the given URI to an {@see Endpoint} of the specified type.
+     * Resolves the given URI to an {@link Endpoint} of the specified type.
      * If the URI has a singleton endpoint registered, then the singleton is returned.
-     * Otherwise, a new {@see Endpoint} is created and if the endpoint is a
+     * Otherwise, a new {@link Endpoint} is created and if the endpoint is a
      * singleton it is registered as a singleton endpoint.
      */
     <T extends Endpoint> T getEndpoint(String name, Class<T> endpointType);
@@ -131,8 +131,6 @@
 
     /**
      * Returns the current routes in this context
-     *
-     * @return the current routes in this context
      */
     List<Route> getRoutes();
 
@@ -170,7 +168,6 @@
 
     /**
      * Returns the converter of exchanges from one type to another
-     * @return
      */
     ExchangeConverter getExchangeConverter();
 

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/CamelExchangeException.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/CamelExchangeException.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/CamelExchangeException.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/CamelExchangeException.java Sun Mar 30 07:47:58 2008
@@ -17,7 +17,7 @@
 package org.apache.camel;
 
 /**
- * An exception caused by a specific message {@ilnk Exchange}
+ * An exception caused by a specific message {@link Exchange}
  *
  * @version $Revision$
  */
@@ -37,8 +37,6 @@
 
     /**
      * Returns the exchange which caused the exception
-     *
-     * @return the exchange which caused the exception
      */
     public Exchange getExchange() {
         return exchange;

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/CamelTemplate.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/CamelTemplate.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/CamelTemplate.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/CamelTemplate.java Sun Mar 30 07:47:58 2008
@@ -62,7 +62,7 @@
      *
      * @param endpointUri the endpoint URI to send the exchange to
      * @param processor   the transformer used to populate the new exchange
-     * @{link Processor} to populate the exchange
+     * {@link Processor} to populate the exchange
      */
     public E send(String endpointUri, Processor processor) {
         Endpoint endpoint = resolveMandatoryEndpoint(endpointUri);
@@ -74,7 +74,7 @@
      *
      * @param endpointUri the endpoint URI to send the exchange to
      * @param processor   the transformer used to populate the new exchange
-     * @{link Processor} to populate the exchange.  The callback
+     * {@link Processor} to populate the exchange.  The callback
      * will be called when the exchange is completed.
      */
     public E send(String endpointUri, Processor processor, AsyncCallback callback) {
@@ -89,7 +89,7 @@
      * @param pattern     the message {@link ExchangePattern} such as
      *                    {@link ExchangePattern#InOnly} or {@link ExchangePattern#InOut}
      * @param processor   the transformer used to populate the new exchange
-     * @{link Processor} to populate the exchange
+     * {@link Processor} to populate the exchange
      */
     public E send(String endpointUri, ExchangePattern pattern, Processor processor) {
         Endpoint endpoint = resolveMandatoryEndpoint(endpointUri);
@@ -113,7 +113,7 @@
      *
      * @param endpoint  the endpoint to send the exchange to
      * @param processor the transformer used to populate the new exchange
-     * @{link Processor} to populate the exchange
+     * {@link Processor} to populate the exchange
      */
     public E send(Endpoint<E> endpoint, Processor processor) {
         return producerCache.send(endpoint, processor);
@@ -124,7 +124,7 @@
      *
      * @param endpoint  the endpoint to send the exchange to
      * @param processor the transformer used to populate the new exchange
-     * @{link Processor} to populate the exchange.  The callback
+     * {@link Processor} to populate the exchange.  The callback
      * will be called when the exchange is completed.
      */
     public E send(Endpoint<E> endpoint, Processor processor, AsyncCallback callback) {
@@ -138,7 +138,7 @@
      * @param pattern   the message {@link ExchangePattern} such as
      *                  {@link ExchangePattern#InOnly} or {@link ExchangePattern#InOut}
      * @param processor the transformer used to populate the new exchange
-     * @{link Processor} to populate the exchange
+     * {@link Processor} to populate the exchange
      */
     public E send(Endpoint<E> endpoint, ExchangePattern pattern, Processor processor) {
         return producerCache.send(endpoint, pattern, processor);
@@ -392,7 +392,7 @@
      * Sends an exchange to the default endpoint using a supplied
      *
      * @param processor the transformer used to populate the new exchange
-     * @{link Processor} to populate the exchange
+     * {@link Processor} to populate the exchange
      */
     public E send(Processor processor) {
         return send(getMandatoryDefaultEndpoint(), processor);

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/Exchange.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/Exchange.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/Exchange.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/Exchange.java Sun Mar 30 07:47:58 2008
@@ -29,6 +29,7 @@
  * @version $Revision$
  */
 public interface Exchange {
+    
     /**
      * Returns the {@link ExchangePattern} (MEP) of this exchange.
      *
@@ -98,7 +99,7 @@
      * Returns the outbound message, lazily creating one if one has not already
      * been associated with this exchange. If you want to inspect this property
      * but not force lazy creation then invoke the {@link #getOut(boolean)}
-     * method passing in null
+     * method passing in <tt>false</tt>
      *
      * @return the response
      */
@@ -130,7 +131,9 @@
      * Returns the fault message; optionally lazily creating one if one has
      * not been associated with this exchange
      *
-     * @return the response
+     * @param lazyCreate <tt>true</tt> will lazy create the fault message
+     *
+     * @return the fault
      */
     Message getFault(boolean lazyCreate);
 
@@ -144,7 +147,7 @@
     /**
      * Sets the exception associated with this exchange
      *
-     * @param e
+     * @param e  the caused exception
      */
     void setException(Throwable e);
 
@@ -166,8 +169,6 @@
 
     /**
      * Creates a new exchange instance with empty messages, headers and properties
-     *
-     * @return
      */
     Exchange newInstance();
 
@@ -179,9 +180,8 @@
 
     /**
      * Copies the data into this exchange from the given exchange
-     * <p/>
-     * #param source is the source from which headers and messages will be
-     * copied
+     * 
+     * @param source is the source from which headers and messages will be copied
      */
     void copyFrom(Exchange source);
 

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/Message.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/Message.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/Message.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/Message.java Sun Mar 30 07:47:58 2008
@@ -28,12 +28,14 @@
 public interface Message {
 
     /**
+     * Returns the id of the message
+     *
      * @return the id of the message
      */
     String getMessageId();
 
     /**
-     * set the id of the message
+     * Sets the id of the message
      *
      * @param messageId
      */
@@ -41,15 +43,13 @@
 
     /**
      * Returns the exchange this message is related to
-     *
-     * @return
      */
     Exchange getExchange();
 
     /**
      * Accesses a specific header
      *
-     * @param name
+     * @param name  name of header
      * @return object header associated with the name
      */
     Object getHeader(String name);

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/NoSuchEndpointException.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/NoSuchEndpointException.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/NoSuchEndpointException.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/NoSuchEndpointException.java Sun Mar 30 07:47:58 2008
@@ -19,8 +19,9 @@
 
 /**
  * A runtime exception thrown if a routing processor such as a
- * {@link RecipientList} is unable to resolve an {@link Endpoint} from a URI.
- * 
+ * {@link org.apache.camel.processor.RecipientList RecipientList} is unable to resolve an
+ * {@link Endpoint} from a URI.
+ *
  * @version $Revision$
  */
 public class NoSuchEndpointException extends RuntimeCamelException {

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/ProducerTemplate.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/ProducerTemplate.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/ProducerTemplate.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/ProducerTemplate.java Sun Mar 30 07:47:58 2008
@@ -33,7 +33,7 @@
      * Sends an exchange to the default endpoint using a supplied
      *
      * @param processor the transformer used to populate the new exchange
-     * @{link Processor} to populate the exchange
+     * {@link Processor} to populate the exchange
      */
     E send(Processor processor);
 
@@ -81,7 +81,7 @@
      *
      * @param endpointUri the endpoint URI to send the exchange to
      * @param processor   the transformer used to populate the new exchange
-     * @{link Processor} to populate the exchange
+     * {@link Processor} to populate the exchange
      */
     E send(String endpointUri, Processor processor);
 
@@ -92,7 +92,7 @@
      * @param pattern     the message {@link ExchangePattern} such as
      *                    {@link ExchangePattern#InOnly} or {@link ExchangePattern#InOut}
      * @param processor   the transformer used to populate the new exchange
-     * @{link Processor} to populate the exchange
+     * {@link Processor} to populate the exchange
      */
     E send(String endpointUri, ExchangePattern pattern, Processor processor);
 
@@ -109,7 +109,7 @@
      *
      * @param endpoint  the endpoint to send the exchange to
      * @param processor the transformer used to populate the new exchange
-     * @{link Processor} to populate the exchange
+     * {@link Processor} to populate the exchange
      */
     E send(Endpoint<E> endpoint, Processor processor);
 
@@ -120,7 +120,7 @@
      * @param pattern   the message {@link ExchangePattern} such as
      *                  {@link ExchangePattern#InOnly} or {@link ExchangePattern#InOut}
      * @param processor the transformer used to populate the new exchange
-     * @{link Processor} to populate the exchange
+     * {@link Processor} to populate the exchange
      */
     E send(Endpoint<E> endpoint, ExchangePattern pattern, Processor processor);
 

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/Route.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/Route.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/Route.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/Route.java Sun Mar 30 07:47:58 2008
@@ -24,7 +24,7 @@
 /**
  * A <a href="http://activemq.apache.org/camel/routes.html">Route</a>
  * defines the processing used on an inbound message exchange
- * from a specific {@see Endpoint} within a {@link CamelContext}
+ * from a specific {@link Endpoint} within a {@link CamelContext}
  *
  * @version $Revision$
  */
@@ -63,8 +63,6 @@
     /**
      * This property map is used to associate information about
      * the route.
-     *
-     * @return
      */
     public Map<String, Object> getProperties() {
         return properties;

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/RuntimeExchangeException.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/RuntimeExchangeException.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/RuntimeExchangeException.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/RuntimeExchangeException.java Sun Mar 30 07:47:58 2008
@@ -17,7 +17,7 @@
 package org.apache.camel;
 
 /**
- * A runtime exception caused by a specific message {@ilnk Exchange}
+ * A runtime exception caused by a specific message {@link Exchange}
  *
  * @version $Revision$
  */
@@ -37,8 +37,6 @@
 
     /**
      * Returns the exchange which caused the exception
-     *
-     * @return the exchange which caused the exception
      */
     public Exchange getExchange() {
         return exchange;

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/RouteBuilder.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/RouteBuilder.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/RouteBuilder.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/RouteBuilder.java Sun Mar 30 07:47:58 2008
@@ -38,9 +38,7 @@
 
 /**
  * A <a href="http://activemq.apache.org/camel/dsl.html">Java DSL</a> which is
- * used to build {@link Route} instances in a
- *
- * @{link CamelContext} for smart routing.
+ * used to build {@link Route} instances in a {@link CamelContext} for smart routing.
  *
  * @version $Revision$
  */
@@ -121,8 +119,6 @@
     /**
      * Adds a route for an interceptor; use the {@link ProcessorType#proceed()} method
      * to continue processing the underying route being intercepted.
-     *
-     * @return
      */
     public InterceptType intercept() {
         return routeCollection.intercept();

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/component/jmx/JMXMessage.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/component/jmx/JMXMessage.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/component/jmx/JMXMessage.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/component/jmx/JMXMessage.java Sun Mar 30 07:47:58 2008
@@ -20,7 +20,7 @@
 import org.apache.camel.impl.DefaultMessage;
 
 /**
- * A {@link Message} for a JMX Notification
+ * A {@link org.apache.camel.Message Message} for a JMX Notification
  * 
  * @version $Revision$
  */

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/converter/jaxp/BytesSource.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/converter/jaxp/BytesSource.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/converter/jaxp/BytesSource.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/converter/jaxp/BytesSource.java Sun Mar 30 07:47:58 2008
@@ -24,7 +24,7 @@
 import javax.xml.transform.stream.StreamSource;
 
 /**
- * A helper class which provides a JAXP {@link Source} from a byte[]
+ * A helper class which provides a JAXP {@link javax.xml.transform.Source Source} from a byte[]
  * which can be read as many times as required.
  *
  * @version $Revision$

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/converter/jaxp/StringSource.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/converter/jaxp/StringSource.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/converter/jaxp/StringSource.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/converter/jaxp/StringSource.java Sun Mar 30 07:47:58 2008
@@ -26,7 +26,7 @@
 import javax.xml.transform.stream.StreamSource;
 
 /**
- * A helper class which provides a JAXP {@link Source} from a String which can
+ * A helper class which provides a JAXP {@link javax.xml.transform.Source Source} from a String which can
  * be read as many times as required.
  * 
  * @version $Revision$

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/converter/jaxp/XmlConverter.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/converter/jaxp/XmlConverter.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/converter/jaxp/XmlConverter.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/converter/jaxp/XmlConverter.java Sun Mar 30 07:47:58 2008
@@ -418,13 +418,6 @@
 
     /**
      * Create a DOM element from the given source.
-     *
-     * @param source
-     * @return
-     * @throws TransformerException
-     * @throws ParserConfigurationException
-     * @throws IOException
-     * @throws SAXException
      */
     @Converter
     public Element toDOMElement(Source source) throws TransformerException, ParserConfigurationException, IOException, SAXException {
@@ -436,10 +429,6 @@
      * Create a DOM element from the DOM node.
      * Simply cast if the node is an Element, or
      * return the root element if it is a Document.
-     *
-     * @param node
-     * @return
-     * @throws TransformerException
      */
     @Converter
     public Element toDOMElement(Node node) throws TransformerException {
@@ -528,13 +517,6 @@
 
     /**
      * Create a DOM document from the given source.
-     *
-     * @param source
-     * @return
-     * @throws TransformerException
-     * @throws ParserConfigurationException
-     * @throws IOException
-     * @throws SAXException
      */
     @Converter
     public Document toDOMDocument(Source source) throws TransformerException, ParserConfigurationException, IOException, SAXException {
@@ -548,11 +530,6 @@
      * if the node is an root element, retrieve its
      * owner element or create a new document and import
      * the node.
-     *
-     * @param node
-     * @return
-     * @throws ParserConfigurationException
-     * @throws TransformerException
      */
     @Converter
     public Document toDOMDocument(Node node) throws ParserConfigurationException, TransformerException {

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/DefaultCamelContext.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/DefaultCamelContext.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/DefaultCamelContext.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/DefaultCamelContext.java Sun Mar 30 07:47:58 2008
@@ -102,9 +102,6 @@
         this.registry = registry;
     }
 
-    /**
-     * Gets the name of the this context.
-     */
     public String getName() {
         return name;
     }
@@ -116,9 +113,6 @@
         this.name = name;
     }
 
-    /**
-     * Adds a component to the container.
-     */
     public void addComponent(String componentName, final Component component) {
         if (component == null) {
             throw new IllegalArgumentException("Component cannot be null");
@@ -167,28 +161,12 @@
         }
     }
 
-    /**
-     * Removes a previously added component.
-     *
-     * @param componentName
-     * @return the previously added component or null if it had not been
-     *         previously added.
-     */
     public Component removeComponent(String componentName) {
         synchronized (components) {
             return components.remove(componentName);
         }
     }
 
-    /**
-     * Gets the a previously added component by name or lazily creates the
-     * component using the factory Callback.
-     *
-     * @param componentName
-     * @param factory used to create a new component instance if the component
-     *                was not previously added.
-     * @return
-     */
     public Component getOrCreateComponent(String componentName, Callable<Component> factory) {
         synchronized (components) {
             Component component = components.get(componentName);
@@ -239,9 +217,6 @@
         return oldEndpoint;
     }
 
-    /**
-     * Resolves the given URI to an endpoint
-     */
     public Endpoint getEndpoint(String uri) {
         Endpoint answer;
         synchronized (endpoints) {
@@ -352,9 +327,6 @@
     // Helper methods
     // -----------------------------------------------------------------------
 
-    /**
-     * Resolves a language for creating expressions
-     */
     public Language resolveLanguage(String language) {
         return getLanguageResolver().resolveLanguage(language, this);
     }

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/DefaultConsumer.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/DefaultConsumer.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/DefaultConsumer.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/DefaultConsumer.java Sun Mar 30 07:47:58 2008
@@ -56,11 +56,9 @@
     }
 
     /**
-     * Provides an {@see AsyncProcessor} interface to the configured
+     * Provides an {@link AsyncProcessor} interface to the configured
      * processor on the consumer.  If the processor does not implement
      * the interface, it will be adapted so that it does.  
-     * 
-     * @return
      */
     public AsyncProcessor getAsyncProcessor() {
         if (asyncProcessor == null) {

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/LoggingExceptionHandler.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/LoggingExceptionHandler.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/LoggingExceptionHandler.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/LoggingExceptionHandler.java Sun Mar 30 07:47:58 2008
@@ -23,7 +23,7 @@
 
 /**
  * A default implementation of {@link ExceptionHandler} which uses a {@link Logger} to
- * log to an arbitrary {@link Log} with some {@link LoggingLevel}
+ * log to an arbitrary {@link org.apache.commons.logging.Log Log} with some {@link LoggingLevel}
  *
  * @version $Revision$
  */

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/MessageSupport.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/MessageSupport.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/MessageSupport.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/MessageSupport.java Sun Mar 30 07:47:58 2008
@@ -89,8 +89,6 @@
 
     /**
      * Returns a new instance
-     * 
-     * @return
      */
     public abstract Message newInstance();
 

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/converter/AnnotationTypeConverterLoader.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/converter/AnnotationTypeConverterLoader.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/converter/AnnotationTypeConverterLoader.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/impl/converter/AnnotationTypeConverterLoader.java Sun Mar 30 07:47:58 2008
@@ -67,11 +67,10 @@
 
     /**
      * Finds the names of the packages to search for on the classpath looking
-     * for text files on the classpath at the
+     * for text files on the classpath at the {@link #META_INF_SERVICES} location.
      *
      * @return a collection of packages to search for
-     * @throws IOException
-     * @{link #META_INF_SERVICES} location
+     * @throws IOException is thrown for IO relatede errors
      */
     protected String[] findPackageNames() throws IOException {
         Set<String> packages = new HashSet<String>();

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/management/CamelNamingStrategy.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/management/CamelNamingStrategy.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/management/CamelNamingStrategy.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/management/CamelNamingStrategy.java Sun Mar 30 07:47:58 2008
@@ -66,9 +66,9 @@
     }
 
     /**
-     * Implements the naming strategy for a {@see CamelContext}.
-     * The convention used for a {@see CamelContext} ObjectName is
-     * "<domain>:context=<context>,name=camel".
+     * Implements the naming strategy for a {@link CamelContext}.
+     * The convention used for a {@link CamelContext} ObjectName is:
+     * <tt>&lt;domain&gt;:context=&lt;context&gt;,name=camel</tt>
      *
      * @param context the camel context
      * @return generated ObjectName
@@ -83,9 +83,9 @@
     }
 
     /**
-     * Implements the naming strategy for a {@see ManagedEndpoint}.
-     * The convention used for a {@see ManagedEndpoint} ObjectName is
-     * "<domain>:context=<context>,type=Endpoints,endpoint=[urlPrefix]localPart".
+     * Implements the naming strategy for a {@link ManagedEndpoint}.
+     * The convention used for a {@link ManagedEndpoint} ObjectName is:
+     * <tt>&lt;domain&gt;:context=&lt;context&gt;,type=Services,endpoint=[urlPrefix]localPart</tt>
      *
      * @param mbean
      * @return generated ObjectName
@@ -104,10 +104,11 @@
     }
 
     /**
-     * Implements the naming strategy for a {@see ServiceSpport Service}.
-     * The convention used for a {@see Service} ObjectName is
-     * "<domain>:context=<context>,type=Services,endpoint=[urlPrefix]localPart".
+     * Implements the naming strategy for a {@link org.apache.camel.impl.ServiceSupport Service}.
+     * The convention used for a {@link org.apache.camel.Service Service} ObjectName is
+     * <tt>&lt;domain&gt;:context=&lt;context&gt;,type=Services,endpoint=[urlPrefix]localPart</tt>
      *
+     * @param context the camel context
      * @param mbean
      * @return generated ObjectName
      * @throws MalformedObjectNameException
@@ -123,9 +124,9 @@
 
 
     /**
-     * Implements the naming strategy for a {@see ManagedRoute}.
-     * The convention used for a {@see ManagedEndpoint} ObjectName is
-     * "<domain>:context=<context>,type=Routes,endpoint=[urlPrefix]localPart".
+     * Implements the naming strategy for a {@link ManagedRoute}.
+     * The convention used for a {@link ManagedEndpoint} ObjectName is:
+     * <tt>&lt;domain&gt;:context=&lt;context&gt;,type=Routes,endpoint=[urlPrefix]localPart</tt>
      *
      * @param mbean
      * @return generated ObjectName
@@ -153,12 +154,13 @@
     }
 
     /**
-     * Implements the naming strategy for a {@see PerformanceCounter}.
-     * The convention used for a {@see ManagedEndpoint} ObjectName is
-     * "<domain>:context=<context>,type=Routes,endpoint=[urlPrefix]localPart".
+     * Implements the naming strategy for a {@link PerformanceCounter}.
+     * The convention used for a {@link ManagedEndpoint} ObjectName is:
+     * <tt>&lt;domain&gt;:context=&lt;context&gt;,type=Routes,endpoint=[urlPrefix]localPart</tt>
+     *
+     * @param context the camel context
      * @param mbean
      * @param routeContext
-     *
      * @return generated ObjectName
      * @throws MalformedObjectNameException
      */

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/ProcessorType.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/ProcessorType.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/RouteContainer.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/RouteContainer.java Sun Mar 30 07:47:58 2008
@@ -25,17 +25,13 @@
  */
 public interface RouteContainer {
     /**
-     * A list of routes
-     *
-     * @return
+     * Returns the routes
      */
     @XmlElementRef
     List<RouteType> getRoutes();
 
     /**
      * Sets the routes to use
-     *
-     * @param routes
      */
     void setRoutes(List<RouteType> routes);
 }

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/config/StreamResequencerConfig.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/config/StreamResequencerConfig.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/config/StreamResequencerConfig.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/config/StreamResequencerConfig.java Sun Mar 30 07:47:58 2008
@@ -82,10 +82,8 @@
      * values for <code>capacity</code> and <code>timeout</code>. Elements
      * of the sequence are compared using the {@link DefaultExchangeComparator}.
      * 
-     * @param capacity
-     *            capacity of the resequencer's inbound queue.
-     * @param timeout.
-     *            minimum time to wait for missing elements (messages).
+     * @param capacity   capacity of the resequencer's inbound queue.
+     * @param timeout    minimum time to wait for missing elements (messages).
      */
     public StreamResequencerConfig(int capacity, long timeout) {
         this(capacity, timeout, new DefaultExchangeComparator());
@@ -97,10 +95,8 @@
      * of the sequence are compared with the given
      * {@link ExpressionResultComparator}.
      * 
-     * @param capacity
-     *            capacity of the resequencer's inbound queue.
-     * @param timeout.
-     *            minimum time to wait for missing elements (messages).
+     * @param capacity   capacity of the resequencer's inbound queue.
+     * @param timeout    minimum time to wait for missing elements (messages).
      */
     public StreamResequencerConfig(int capacity, long timeout, ExpressionResultComparator<Exchange> comparator) {
         this.capacity = capacity;

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/language/ExpressionType.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/language/ExpressionType.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/language/ExpressionType.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/language/ExpressionType.java Sun Mar 30 07:47:58 2008
@@ -206,9 +206,7 @@
 
     /**
      * Allows derived classes to set a lazily created expressionType instance
-     * such as if using the {@link ExpressionClause#
-     *
-     * @param expressionType
+     * such as if using the {@link ExpressionClause}
      */
     protected void setExpressionType(ExpressionType expressionType) {
         this.expressionType = expressionType;

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/Aggregator.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/Aggregator.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/Aggregator.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/Aggregator.java Sun Mar 30 07:47:58 2008
@@ -29,20 +29,17 @@
  * href="http://activemq.apache.org/camel/aggregator.html">Aggregator</a>
  * pattern where a batch of messages are processed (up to a maximum amount or
  * until some timeout is reached) and messages for the same correlation key are
- * combined together using some kind of
- * {@link AggregationStrategy ) (by default the latest message is used) to compress
- * many message exchanges * into a smaller number of exchanges. <p/> A good
- * example of this is stock market data; you may be receiving 30,000
+ * combined together using some kind of {@link AggregationStrategy}
+ * (by default the latest message is used) to compress many message exchanges
+ * into a smaller number of exchanges.
+ * <p/>
+ * A good example of this is stock market data; you may be receiving 30,000
  * messages/second and you may want to throttle it right down so that multiple
  * messages for the same stock are combined (or just the latest message is used
- * and older prices are discarded). Another idea is to combine line item
- * messages together into a single invoice message.
+ * and older prices are discarded). Another idea is to combine line item messages
+ * together into a single invoice message.
  *
  * @version $Revision$
- * @param correlationExpression the expression used to calculate the correlation
- *                key. For a JMS message this could be the expression
- *                <code>header("JMSDestination")</code> or
- *                <code>header("JMSCorrelationID")</code>
  */
 public class Aggregator extends BatchProcessor {
     private Predicate aggregationCompletedPredicate;

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/ErrorHandlerSupport.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/ErrorHandlerSupport.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/ErrorHandlerSupport.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/ErrorHandlerSupport.java Sun Mar 30 07:47:58 2008
@@ -45,10 +45,6 @@
 
     /**
      * Attempts to invoke the handler for this particular exception if one is available
-     *
-     * @param exchange
-     * @param exception
-     * @return
      */
     protected boolean customProcessorForException(Exchange exchange, Throwable exception) throws Exception {
         ExceptionType policy = getExceptionPolicy(exchange, exception);

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/loadbalancer/TopicLoadBalancer.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/loadbalancer/TopicLoadBalancer.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/loadbalancer/TopicLoadBalancer.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/loadbalancer/TopicLoadBalancer.java Sun Mar 30 07:47:58 2008
@@ -38,10 +38,11 @@
 
     /**
      * Strategy method to copy the exchange before sending to another endpoint.
-     * Derived classes such as the {@link Pipeline} will not clone the exchange
+     * Derived classes such as the {@link org.apache.camel.processor.Pipeline Pipeline}
+     * will not clone the exchange
      * 
      * @param processor the processor that will send the exchange
-     * @param exchange
+     * @param exchange  the exchange
      * @return the current exchange if no copying is required such as for a
      *         pipeline otherwise a new copy of the exchange is returned.
      */

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/spi/LifecycleStrategy.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/spi/LifecycleStrategy.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/spi/LifecycleStrategy.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/spi/LifecycleStrategy.java Sun Mar 30 07:47:58 2008
@@ -27,27 +27,27 @@
 
 public interface LifecycleStrategy {
     /**
-     * Notification on adding a {@see CamelContext}.
+     * Notification on adding a {@link CamelContext}.
      */
     void onContextCreate(CamelContext context);
 
     /**
-     * Notification on adding an {@see Endpoint}.
+     * Notification on adding an {@link Endpoint}.
      */
     void onEndpointAdd(Endpoint<? extends Exchange> endpoint);
 
     /**
-     * Notification on adding a {@see Service}.
+     * Notification on adding a {@link Service}.
      */
     void onServiceAdd(CamelContext context, Service service);
 
     /**
-     * Notification on adding {@see Route}(s).
+     * Notification on adding {@link Route}(s).
      */
     void onRoutesAdd(Collection<Route> routes);
 
     /**
-     * Notification on adding {@see RouteContext}(s).
+     * Notification on adding {@link RouteContext}(s).
      *
      * @param routeContext
      */

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/spi/TypeConverterAware.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/spi/TypeConverterAware.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/spi/TypeConverterAware.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/spi/TypeConverterAware.java Sun Mar 30 07:47:58 2008
@@ -22,7 +22,8 @@
  * An interface for an object which is interested in being injected with the root {@link TypeConverter}
  * such as for implementing a fallback type converter
  *
- * @see DefaultTypeConverter#addFallbackConverter(TypeConverter) 
+ * @see org.apache.camel.impl.converter.DefaultTypeConverter#addFallbackConverter(TypeConverter)
+ *         DefaultTypeConverter.addFallbackConverter
  * @version $Revision$
  */
 public interface TypeConverterAware {

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/CamelContextHelper.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/CamelContextHelper.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/CamelContextHelper.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/CamelContextHelper.java Sun Mar 30 07:47:58 2008
@@ -46,10 +46,6 @@
     /**
      * Returns the mandatory endpoint for the given URI or the
      * {@link org.apache.camel.NoSuchEndpointException} is thrown
-     *
-     * @param camelContext
-     * @param uri
-     * @return
      */
     public static Endpoint getMandatoryEndpoint(CamelContext camelContext, String uri)
         throws NoSuchEndpointException {
@@ -147,10 +143,6 @@
 
     /**
      * Resolves the given language name into a {@link Language} or throws an exception if it could not be converted
-     *
-     * @param camelContext
-     * @param languageName
-     * @return
      */
     public static Language resolveMandatoryLanguage(CamelContext camelContext, String languageName) {
         notNull(camelContext, "camelContext");

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/DefaultTimeoutMap.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/DefaultTimeoutMap.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/DefaultTimeoutMap.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/DefaultTimeoutMap.java Sun Mar 30 07:47:58 2008
@@ -171,9 +171,6 @@
 
     /**
      * A hook to allow derivations to avoid evicting the current entry
-     *
-     * @param entry
-     * @return
      */
     protected boolean isValidForEviction(TimeoutMapEntry entry) {
         return true;

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/ExchangeHelper.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/ExchangeHelper.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/ExchangeHelper.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/ExchangeHelper.java Sun Mar 30 07:47:58 2008
@@ -253,7 +253,6 @@
      *
      * @param exchange the exchange to make available
      * @param map      the map to populate
-     * @return a Map populated with the require dvariables
      */
     public static void populateVariableMap(Exchange exchange, Map map) {
         map.put("exchange", exchange);

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/ObjectHelper.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/ObjectHelper.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/ObjectHelper.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/ObjectHelper.java Sun Mar 30 07:47:58 2008
@@ -210,7 +210,7 @@
      * if the first element is a boolean its value is used otherwise this method
      * returns true if the collection is not empty
      *
-     * @returns true if the first element is a boolean and its value is true or
+     * @return <tt>true</tt> if the first element is a boolean and its value is true or
      *          if the list is non empty
      */
     public static boolean matches(List list) {

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/ProducerCache.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/ProducerCache.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/ProducerCache.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/ProducerCache.java Sun Mar 30 07:47:58 2008
@@ -72,7 +72,7 @@
 
     /**
      * Sends an exchange to an endpoint using a supplied
-     * @{link Processor} to populate the exchange
+     * {@link Processor} to populate the exchange
      *
      * @param endpoint the endpoint to send the exchange to
      * @param processor the transformer used to populate the new exchange
@@ -89,7 +89,7 @@
 
     /**
      * Sends an exchange to an endpoint using a supplied
-     * @{link Processor} to populate the exchange.  The callback
+     * {@link Processor} to populate the exchange.  The callback
      * will be called when the exchange is completed.
      *
      * @param endpoint the endpoint to send the exchange to
@@ -118,7 +118,7 @@
 
     /**
      * Sends an exchange to an endpoint using a supplied
-     * @{link Processor} to populate the exchange
+     * {@link Processor} to populate the exchange
      *
      * @param endpoint the endpoint to send the exchange to
      * @param pattern the message {@link ExchangePattern} such as

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/jndi/JndiContext.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/jndi/JndiContext.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/jndi/JndiContext.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/util/jndi/JndiContext.java Sun Mar 30 07:47:58 2008
@@ -146,11 +146,6 @@
      * from the next context, plus the context it just created (if it in fact
      * created it). (the names are suitably extended by the segment originally
      * lopped off).
-     *
-     * @param name
-     * @param value
-     * @return
-     * @throws javax.naming.NamingException
      */
     protected Map internalBind(String name, Object value) throws NamingException {
         assert name != null && name.length() > 0;

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/view/NodeData.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/view/NodeData.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/view/NodeData.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/view/NodeData.java Sun Mar 30 07:47:58 2008
@@ -167,10 +167,7 @@
     }
 
     /**
-     * lets insert a space before each upper case letter after a lowercase
-     *
-     * @param name
-     * @return
+     * Lets insert a space before each upper case letter after a lowercase
      */
     public static String insertSpacesBetweenCamelCase(String name) {
         boolean lastCharacterLowerCase = false;
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/ProcessorType.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/ProcessorType.java Sun Mar 30 07:47:58 2008
@@ -172,14 +172,14 @@
      * interfering with each other.
      * @param aggregationStrategy the strategy used to aggregate responses for
      *          every part
      * @param pralleProcessing if is true camel will fork thread to call the endpoint producer
      * @return the multicast type
      */
-    public MulticastType multicast(AggregationStrategy aggregationStrategy, boolean paralleProcessing) {
+    public MulticastType multicast(AggregationStrategy aggregationStrategy, boolean parallelProcessing) {
         MulticastType answer = new MulticastType();
         addOutput(answer);
         answer.setAggregationStrategy(aggregationStrategy);
-        answer.setParallelProcessing(true);
+        answer.setParallelProcessing(parallelProcessing);
         return answer;
     }
 
@@ -391,8 +391,8 @@
      * href="http://activemq.apache.org/camel/routing-slip.html">Routing
      * Slip</a> pattern.
      *
-     * @param header is the header that the {@link RoutingSlip} class will
-     * look in for the list of URIs to route the message to.
+     * @param header is the header that the {@link org.apache.camel.processor.RoutingSlip RoutingSlip}
+     * class will look in for the list of URIs to route the message to.
      * @param uriDelimiter is the delimiter that will be used to split up
      * the list of URIs in the routing slip.
      */
@@ -407,8 +407,8 @@
      * href="http://activemq.apache.org/camel/routing-slip.html">Routing
      * Slip</a> pattern.
      *
-     * @param header is the header that the {@link RoutingSlip} class will
-     * look in for the list of URIs to route the message to. The list of URIs
+     * @param header is the header that the {@link org.apache.camel.processor.RoutingSlip RoutingSlip}
+     * class will look in for the list of URIs to route the message to. The list of URIs
      * will be split based on the default delimiter 
      * {@link RoutingSlipType#DEFAULT_DELIMITER}.
      */
@@ -569,19 +569,15 @@
      * href="http://activemq.apache.org/camel/aggregator.html">Aggregator</a>
      * pattern where a batch of messages are processed (up to a maximum amount
      * or until some timeout is reached) and messages for the same correlation
-     * key are combined together using some kind of
-     * {@link AggregationStrategy ) (by default the latest message is used) to compress many message exchanges
-     * into a smaller number of exchanges. <p/> A good example of this is stock
-     * market data; you may be receiving 30,000 messages/second and you may want
-     * to throttle it right down so that multiple messages for the same stock
-     * are combined (or just the latest message is used and older prices are
-     * discarded). Another idea is to combine line item messages together into a
-     * single invoice message.
-     *
-     * @param correlationExpression the expression used to calculate the
-     *                              correlation key. For a JMS message this could be the
-     *                              expression <code>header("JMSDestination")</code> or
-     *                              <code>header("JMSCorrelationID")</code>
+     * key are combined together using some kind of {@link AggregationStrategy}
+     * (by default the latest message is used) to compress many message exchanges
+     * into a smaller number of exchanges.
+     * <p/>
+     * A good example of this is stock market data; you may be receiving 30,000
+     * messages/second and you may want to throttle it right down so that multiple
+     * messages for the same stock are combined (or just the latest message is used
+     * and older prices are discarded). Another idea is to combine line item messages
+     * together into a single invoice message.
      */
     public ExpressionClause<AggregatorType> aggregator() {
         AggregatorType answer = new AggregatorType();
@@ -594,14 +590,15 @@
      * href="http://activemq.apache.org/camel/aggregator.html">Aggregator</a>
      * pattern where a batch of messages are processed (up to a maximum amount
      * or until some timeout is reached) and messages for the same correlation
-     * key are combined together using some kind of
-     * {@link AggregationStrategy ) (by default the latest message is used) to compress many message exchanges
-     * into a smaller number of exchanges. <p/> A good example of this is stock
-     * market data; you may be receiving 30,000 messages/second and you may want
-     * to throttle it right down so that multiple messages for the same stock
-     * are combined (or just the latest message is used and older prices are
-     * discarded). Another idea is to combine line item messages together into a
-     * single invoice message.
+     * key are combined together using some kind of {@link AggregationStrategy}
+     * (by default the latest message is used) to compress many message exchanges
+     * into a smaller number of exchanges.
+     * <p/>
+     * A good example of this is stock market data; you may be receiving 30,000
+     * messages/second and you may want to throttle it right down so that multiple
+     * messages for the same stock are combined (or just the latest message is used
+     * and older prices are discarded). Another idea is to combine line item messages
+     * together into a single invoice message.
      *
      * @param aggregationStrategy the strategy used for the aggregation
      */
@@ -627,18 +624,19 @@
     }
 
     /**
-     * Creates the <a
+     * Creates an <a
      * href="http://activemq.apache.org/camel/aggregator.html">Aggregator</a>
      * pattern where a batch of messages are processed (up to a maximum amount
      * or until some timeout is reached) and messages for the same correlation
-     * key are combined together using some kind of
-     * {@link AggregationStrategy ) (by default the latest message is used) to compress many message exchanges
-     * into a smaller number of exchanges. <p/> A good example of this is stock
-     * market data; you may be receiving 30,000 messages/second and you may want
-     * to throttle it right down so that multiple messages for the same stock
-     * are combined (or just the latest message is used and older prices are
-     * discarded). Another idea is to combine line item messages together into a
-     * single invoice message.
+     * key are combined together using some kind of {@link AggregationStrategy}
+     * (by default the latest message is used) to compress many message exchanges
+     * into a smaller number of exchanges.
+     * <p/>
+     * A good example of this is stock market data; you may be receiving 30,000
+     * messages/second and you may want to throttle it right down so that multiple
+     * messages for the same stock are combined (or just the latest message is used
+     * and older prices are discarded). Another idea is to combine line item messages
+     * together into a single invoice message.
      *
      * @param correlationExpression the expression used to calculate the
      *                              correlation key. For a JMS message this could be the
@@ -652,18 +650,19 @@
     }
 
     /**
-     * Creates the <a
+     * Creates an <a
      * href="http://activemq.apache.org/camel/aggregator.html">Aggregator</a>
      * pattern where a batch of messages are processed (up to a maximum amount
      * or until some timeout is reached) and messages for the same correlation
-     * key are combined together using some kind of
-     * {@link AggregationStrategy ) (by default the latest message is used) to compress many message exchanges
-     * into a smaller number of exchanges. <p/> A good example of this is stock
-     * market data; you may be receiving 30,000 messages/second and you may want
-     * to throttle it right down so that multiple messages for the same stock
-     * are combined (or just the latest message is used and older prices are
-     * discarded). Another idea is to combine line item messages together into a
-     * single invoice message.
+     * key are combined together using some kind of {@link AggregationStrategy}
+     * (by default the latest message is used) to compress many message exchanges
+     * into a smaller number of exchanges.
+     * <p/>
+     * A good example of this is stock market data; you may be receiving 30,000
+     * messages/second and you may want to throttle it right down so that multiple
+     * messages for the same stock are combined (or just the latest message is used
+     * and older prices are discarded). Another idea is to combine line item messages
+     * together into a single invoice message.
      *
      * @param correlationExpression the expression used to calculate the
      *                              correlation key. For a JMS message this could be the
@@ -837,8 +836,6 @@
     /**
      * Trace logs the exchange before it goes to the next processing step using
      * the {@link #DEFAULT_TRACE_CATEGORY} logging category.
-     *
-     * @return
      */
     public Type trace() {
         return trace(DEFAULT_TRACE_CATEGORY);
@@ -849,7 +846,6 @@
      * the specified logging category.
      *
      * @param category the logging category trace messages will sent to.
-     * @return
      */
     public Type trace(String category) {
         final Log log = LogFactory.getLog(category);
@@ -1289,8 +1285,6 @@
 
     /**
      * Returns a label to describe this node such as the expression if some kind of expression node
-     *
-     * @return
      */
     public String getLabel() {
         return "";
@@ -172,14 +172,14 @@
      * @param aggregationStrategy the strategy used to aggregate responses for
      *          every part
-     * @param pralleProcessing if is true camel will fork thread to call the endpoint producer
+     * @param parallelProcessing if is <tt>true</tt> camel will fork thread to call the endpoint producer
      * @return the multicast type
      */

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/RouteContainer.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/RouteContainer.java?rev=642753&r1=642752&r2=642753&view=diff
==============================================================================